# Relation Mapping Between Jira Service Management and SAP LeanIX
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix#prerequisites)
  * [Synchronization Scope](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix#synchronization-scope)
  * [Step 1: Start the Mapping Wizard](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix#step-1:-start-the-mapping-wizard)
  * [Step 2: Define the Source System](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix#step-2:-define-the-source-system)
  * [Step 3: Define Relation Endpoints](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix#step-3:-define-relation-endpoints)
  * [Step 4: Define Relation Type Mapping](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix#step-4:-define-relation-type-mapping)
  * [Relation Mapping Parameters](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix#relation-mapping-parameters)


View all
Configure relation mappings to synchronize relationships and dependencies between Jira Service Management and SAP LeanIX.
